@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -80,8 +79,10 @@ from .util.future import with_metaclass
 __all__ = (
     'ButtonClick',
     'DoubleTap',
+    'Event',
     'LODStart',
     'LODEnd',
+    'MenuItemClick',
     'MouseEnter',
     'MouseLeave',
     'MouseMove',
@@ -92,9 +93,13 @@ __all__ = (
     'Pinch',
     'PinchEnd',
     'PinchStart',
+    'Rotate',
+    'RotateEnd',
+    'RotateStart',
     'PlotEvent',
     'PointEvent',
     'Press',
+    'PressUp',
     'Reset',
     'SelectionGeometry',
     'Tap',
@@ -143,7 +148,7 @@ class Event(with_metaclass(_MetaEvent, object)):
         '''
         self._model_id = None
         if model is not None:
-            self._model_id = model._id
+            self._model_id = model.id
 
     @classmethod
     def decode_json(cls, dct):
@@ -170,7 +175,7 @@ class Event(with_metaclass(_MetaEvent, object)):
                 <bokeh.events.Pan object at 0x1040f84a8>
 
         '''
-        if not (('event_name' in dct) and ('event_values' in dct)):
+        if not ('event_name' in dct and 'event_values' in dct):
             return dct
 
         event_name = dct['event_name']
@@ -185,18 +190,28 @@ class Event(with_metaclass(_MetaEvent, object)):
         return event
 
 class ButtonClick(Event):
-    ''' Announce a button click event on a Bokeh Button widget.
+    ''' Announce a button click event on a Bokeh button widget.
 
     '''
     event_name = 'button_click'
 
     def __init__(self, model):
-        from .models.widgets import Button
-        if model is not None and not isinstance(model, Button):
-            msg ='{clsname} event only applies to Button models'
+        from .models.widgets import AbstractButton
+        if model is not None and not isinstance(model, AbstractButton):
+            msg ='{clsname} event only applies to button models'
             raise ValueError(msg.format(clsname=self.__class__.__name__))
         super(ButtonClick, self).__init__(model=model)
 
+class MenuItemClick(Event):
+    ''' Announce a button click event on a Bokeh menu item.
+
+    '''
+    event_name = 'menu_item_click'
+
+    def __init__(self, model, item=None):
+        self.item = item
+        super(MenuItemClick, self).__init__(model=model)
+
 class PlotEvent(Event):
     ''' The base class for all events applicable to Plot models.
 
@@ -318,6 +333,18 @@ class Press(PointEvent):
     '''
     event_name = 'press'
 
+class PressUp(PointEvent):
+    ''' Announce a pressup event on a Bokeh plot.
+
+    Attributes:
+        sx (float) : x-coordinate of the event in *screen* space
+        sy (float) : y-coordinate of the event in *screen* space
+        x (float) : x-coordinate of the event in *data* space
+        y (float) : y-coordinate of the event in *data* space
+
+    '''
+    event_name = 'pressup'
+
 class MouseEnter(PointEvent):
     ''' Announce a mouse enter event onto a Bokeh plot.
 
@@ -484,6 +511,56 @@ class PinchStart(PointEvent):
     '''
     event_name = 'pinchstart'
 
+class Rotate(PointEvent):
+    ''' Announce a rotate event on a Bokeh plot.
+
+    Attributes:
+        rotation (float) : the rotation that has been done (in deg)
+        sx (float) : x-coordinate of the event in *screen* space
+        sy (float) : y-coordinate of the event in *screen* space
+        x (float) : x-coordinate of the event in *data* space
+        y (float) : y-coordinate of the event in *data* space
+
+    .. note::
+        This event is only applicable for touch-enabled devices.
+
+    '''
+    event_name = 'rotate'
+
+    def __init__(self, model, rotation=None, **kwargs):
+        self.rotation = rotation
+        super(Rotate, self).__init__(model, **kwargs)
+
+class RotateEnd(PointEvent):
+    ''' Announce the end of a rotate event on a Bokeh plot.
+
+    Attributes:
+        sx (float) : x-coordinate of the event in *screen* space
+        sy (float) : y-coordinate of the event in *screen* space
+        x (float) : x-coordinate of the event in *data* space
+        y (float) : y-coordinate of the event in *data* space
+
+    .. note::
+        This event is only applicable for touch-enabled devices.
+
+    '''
+    event_name = 'rotateend'
+
+class RotateStart(PointEvent):
+    ''' Announce the start of a rotate event on a Bokeh plot.
+
+    Attributes:
+        sx (float) : x-coordinate of the event in *screen* space
+        sy (float) : y-coordinate of the event in *screen* space
+        x (float) : x-coordinate of the event in *data* space
+        y (float) : y-coordinate of the event in *data* space
+
+    .. note::
+        This event is only applicable for touch-enabled devices.
+
+    '''
+    event_name = 'rotatestart'
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
