@@ -1,20 +1,41 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Models for representing top-level plot objects.
 
 '''
-from __future__ import absolute_import
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+import logging
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
 import warnings
 
+# External imports
 from six import string_types
 
-from ..core.enums import Location, OutputBackend
+# Bokeh imports
+from ..core.enums import Location, OutputBackend, ResetPolicy
 from ..core.properties import Bool, Dict, Enum, Include, Instance, Int, List, Override, String, Float
 from ..core.property_mixins import LineProps, FillProps
 from ..core.query import find
 from ..core.validation import error, warning
-from ..core.validation.errors import  BAD_EXTRA_RANGE_NAME, REQUIRED_RANGE, REQUIRED_SCALE, INCOMPATIBLE_SCALE_AND_RANGE
-from ..core.validation.warnings import MISSING_RENDERERS
-from ..model import Model
+from ..core.validation.errors import BAD_EXTRA_RANGE_NAME, REQUIRED_RANGE, REQUIRED_SCALE, INCOMPATIBLE_SCALE_AND_RANGE
+from ..core.validation.warnings import MISSING_RENDERERS, FIXED_SIZING_MODE, FIXED_WIDTH_POLICY, FIXED_HEIGHT_POLICY
+from ..model import Model, collect_filtered_models
+from ..util.deprecation import deprecated
 from ..util.string import nice_join
 
 from .annotations import Legend, Title
@@ -28,70 +49,17 @@ from .scales import Scale, CategoricalScale, LinearScale, LogScale
 from .sources import DataSource, ColumnDataSource
 from .tools import Tool, Toolbar, HoverTool
 
-def _check_conflicting_kwargs(a1, a2, kwargs):
-    if a1 in kwargs and a2 in kwargs:
-        raise ValueError("Conflicting properties set on plot: %r and %r" % (a1, a2))
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
 
-class _list_attr_splat(list):
-    def __setattr__(self, attr, value):
-        for x in self:
-            setattr(x, attr, value)
+__all__ = (
+    'Plot',
+)
 
-    def __dir__(self):
-        if len(set(type(x) for x in self)) == 1:
-            return dir(self[0])
-        else:
-            return dir(self)
-
-_LEGEND_EMPTY_WARNING = """
-You are attemptings to set `plot.legend.%s` on a plot that has zero legends added, this will have no effect.
-
-Before legend properties can be set, you must add a Legend explicitly, or call a glyph method with the 'legend' parameter set.
-"""
-
-class _legend_attr_splat(_list_attr_splat):
-    def __setattr__(self, attr, value):
-        if not len(self):
-            warnings.warn(_LEGEND_EMPTY_WARNING % attr)
-        return super(_legend_attr_splat, self).__setattr__(attr, value)
-
-def _select_helper(args, kwargs):
-    """ Allow flexible selector syntax.
-
-    Returns:
-        dict
-
-    """
-    if len(args) > 1:
-        raise TypeError("select accepts at most ONE positional argument.")
-
-    if len(args) > 0 and len(kwargs) > 0:
-        raise TypeError("select accepts EITHER a positional argument, OR keyword arguments (not both).")
-
-    if len(args) == 0 and len(kwargs) == 0:
-        raise TypeError("select requires EITHER a positional argument, OR keyword arguments.")
-
-    if args:
-        arg = args[0]
-        if isinstance(arg, dict):
-            selector = arg
-        elif isinstance(arg, string_types):
-            selector = dict(name=arg)
-        elif isinstance(arg, type) and issubclass(arg, Model):
-            selector = {"type": arg}
-        else:
-            raise TypeError("selector must be a dictionary, string or plot object.")
-
-    elif 'selector' in kwargs:
-        if len(kwargs) == 1:
-            selector = kwargs['selector']
-        else:
-            raise TypeError("when passing 'selector' keyword arg, not other keyword args may be present")
-
-    else:
-        selector = kwargs
-
-    return selector
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
 
 class Plot(LayoutDOM):
     ''' Model representing a plot, containing glyphs, guides, annotations.
@@ -114,7 +82,7 @@ class Plot(LayoutDOM):
 
         Additionally, for compatibility with ``Model.select``, a selector
         dict may be passed as ``selector`` keyword argument, in which case
-        the value of ``kwargs['selector']`` is used for th query.
+        the value of ``kwargs['selector']`` is used for the query.
 
         For convenience, queries on just names can be made by supplying
         the ``name`` string as the single parameter:
@@ -214,7 +182,8 @@ class Plot(LayoutDOM):
         ''' Splattable list of :class:`~bokeh.models.annotations.Legend` objects.
 
         '''
-        legends = [obj for obj in self.renderers if isinstance(obj, Legend)]
+        panels = self.above + self.below + self.left + self.right + self.center
+        legends = [obj for obj in panels if isinstance(obj, Legend)]
         return _legend_attr_splat(legends)
 
     @property
@@ -226,7 +195,7 @@ class Plot(LayoutDOM):
         return _list_attr_splat(hovers)
 
     def _grid(self, dimension):
-        grid = [obj for obj in self.renderers if isinstance(obj, Grid) and obj.dimension==dimension]
+        grid = [obj for obj in self.center if isinstance(obj, Grid) and obj.dimension == dimension]
         return _list_attr_splat(grid)
 
     @property
@@ -276,15 +245,7 @@ class Plot(LayoutDOM):
                 "Invalid place '%s' specified. Valid place values are: %s" % (place, nice_join(valid_places))
             )
 
-        if hasattr(obj, 'plot'):
-            if obj.plot is not None:
-                raise ValueError("object to be added already has 'plot' attribute set")
-            obj.plot = self
-
-        self.renderers.append(obj)
-
-        if place is not 'center':
-            getattr(self, place).append(obj)
+        getattr(self, place).append(obj)
 
     def add_tools(self, *tools):
         ''' Adds tools to the plot.
@@ -300,9 +261,6 @@ class Plot(LayoutDOM):
             if not isinstance(tool, Tool):
                 raise ValueError("All arguments to add_tool must be Tool subclasses.")
 
-            if hasattr(tool, 'overlay'):
-                self.renderers.append(tool.overlay)
-
             self.toolbar.tools.append(tool)
 
     def add_glyph(self, source_or_glyph, glyph=None, **kw):
@@ -410,8 +368,9 @@ class Plot(LayoutDOM):
 
     @error(BAD_EXTRA_RANGE_NAME)
     def _check_bad_extra_range_name(self):
-        msg = ""
-        for ref in self.references():
+        msg  = ""
+        filt = lambda x: x is not self and isinstance(x, Plot)
+        for ref in collect_filtered_models(filt, self):
             prop_names = ref.properties()
             bad = []
             if 'x_range_name' in prop_names and 'y_range_name' in prop_names:
@@ -525,26 +484,37 @@ class Plot(LayoutDOM):
     A list of renderers to occupy the area below of the plot.
     """)
 
-    plot_height = Int(600, help="""
-    Total height of the entire plot (including any axes, titles,
-    border padding, etc.)
-
-    .. note::
-        This corresponds directly to the height of the HTML
-        canvas that will be used.
-
+    center = List(Instance(Renderer), help="""
+    A list of renderers to occupy the center area (frame) of the plot.
     """)
 
     plot_width = Int(600, help="""
-    Total width of the entire plot (including any axes, titles,
-    border padding, etc.)
+    The outer width of a plot, including any axes, titles, border padding, etc.
 
     .. note::
-        This corresponds directly to the width of the HTML
-        canvas that will be used.
+        This corresponds directly to the width of the HTML canvas.
 
     """)
 
+    plot_height = Int(600, help="""
+    The outer height of a plot, including any axes, titles, border padding, etc.
+
+    .. note::
+        This corresponds directly to the height of the HTML canvas.
+
+    """)
+
+    frame_width = Int(default=None, help="""
+    The width of a plot frame or the inner width of a plot, excluding any
+    axes, titles, border padding, etc.
+    """)
+
+    frame_height = Int(default=None, help="""
+    The height of a plot frame or the inner height of a plot, excluding any
+    axes, titles, border padding, etc.
+    """)
+
+
     inner_width = Int(readonly=True, help="""
     This is the exact width of the plotting canvas, i.e. the width of
     the actual plot, without toolbars etc. Note this is computed in a
@@ -567,7 +537,7 @@ class Plot(LayoutDOM):
 
     """)
 
-    layout_width = Int(readonly=True, help="""
+    outer_width = Int(readonly=True, help="""
     This is the exact width of the layout, i.e. the height of
     the actual plot, with toolbars etc. Note this is computed in a
     web browser, so this property will work only in backends capable of
@@ -578,7 +548,7 @@ class Plot(LayoutDOM):
 
     """)
 
-    layout_height = Int(readonly=True, help="""
+    outer_height = Int(readonly=True, help="""
     This is the exact height of the layout, i.e. the height of
     the actual plot, with toolbars etc. Note this is computed in a
     web browser, so this property will work only in backends capable of
@@ -647,15 +617,22 @@ class Plot(LayoutDOM):
     it will override ``min_border``.
     """)
 
-    h_symmetry = Bool(True, help="""
-    Whether the total horizontal padding on both sides of the plot will
-    be made equal (the left or right padding amount, whichever is larger).
-    """)
 
-    v_symmetry = Bool(False, help="""
-    Whether the total vertical padding on both sides of the plot will
-    be made equal (the top or bottom padding amount, whichever is larger).
-    """)
+    @property
+    def h_symmetry(self):
+        deprecated("h_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
+
+    @h_symmetry.setter
+    def h_symmetry(self, _):
+        deprecated("h_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
+
+    @property
+    def v_symmetry(self):
+        deprecated("v_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
+
+    @v_symmetry.setter
+    def v_symmetry(self, _):
+        deprecated("v_symmetry has been non-functional since before Bokeh 1.0 and will be removed at Bokeh 2.0")
 
     lod_factor = Int(10, help="""
     Decimation factor to use when applying level-of-detail decimation.
@@ -722,3 +699,112 @@ class Plot(LayoutDOM):
     .. note::
         This setting only takes effect if ``match_aspect`` is set to ``True``.
     """)
+
+    reset_policy = Enum(ResetPolicy, default="standard", help="""
+    How a plot should respond to being reset. By deafult, the standard actions
+    are to clear any tool state history, return plot ranges to their original
+    values, undo all selections, and emit a ``Reset`` event. If customization
+    is desired, this property may be set to ``"event_only"``, which will
+    suppress all of the actions except the Reset event.
+    """)
+
+    # XXX: override LayoutDOM's definitions because of plot_{width,height}.
+    @error(FIXED_SIZING_MODE)
+    def _check_fixed_sizing_mode(self):
+        pass
+
+    @error(FIXED_WIDTH_POLICY)
+    def _check_fixed_width_policy(self):
+        pass
+
+    @error(FIXED_HEIGHT_POLICY)
+    def _check_fixed_height_policy(self):
+        pass
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+def _check_conflicting_kwargs(a1, a2, kwargs):
+    if a1 in kwargs and a2 in kwargs:
+        raise ValueError("Conflicting properties set on plot: %r and %r" % (a1, a2))
+
+class _list_attr_splat(list):
+    def __setattr__(self, attr, value):
+        for x in self:
+            setattr(x, attr, value)
+    def __getattribute__(self, attr):
+        if attr in dir(list):
+            return list.__getattribute__(self, attr)
+        if len(self) == 0:
+            raise AttributeError("Trying to access %r attribute on an empty 'splattable' list" % attr)
+        if len(self) == 1:
+            return getattr(self[0], attr)
+        try:
+            return _list_attr_splat([getattr(x, attr) for x in self])
+        except Exception:
+            raise AttributeError("Trying to access %r attribute on a 'splattable' list, but list items have no %r attribute" % (attr, attr))
+
+    def __dir__(self):
+        if len(set(type(x) for x in self)) == 1:
+            return dir(self[0])
+        else:
+            return dir(self)
+
+_LEGEND_EMPTY_WARNING = """
+You are attempting to set `plot.legend.%s` on a plot that has zero legends added, this will have no effect.
+
+Before legend properties can be set, you must add a Legend explicitly, or call a glyph method with a legend parameter set.
+"""
+
+class _legend_attr_splat(_list_attr_splat):
+    def __setattr__(self, attr, value):
+        if not len(self):
+            warnings.warn(_LEGEND_EMPTY_WARNING % attr)
+        return super(_legend_attr_splat, self).__setattr__(attr, value)
+
+def _select_helper(args, kwargs):
+    """ Allow flexible selector syntax.
+
+    Returns:
+        dict
+
+    """
+    if len(args) > 1:
+        raise TypeError("select accepts at most ONE positional argument.")
+
+    if len(args) > 0 and len(kwargs) > 0:
+        raise TypeError("select accepts EITHER a positional argument, OR keyword arguments (not both).")
+
+    if len(args) == 0 and len(kwargs) == 0:
+        raise TypeError("select requires EITHER a positional argument, OR keyword arguments.")
+
+    if args:
+        arg = args[0]
+        if isinstance(arg, dict):
+            selector = arg
+        elif isinstance(arg, string_types):
+            selector = dict(name=arg)
+        elif isinstance(arg, type) and issubclass(arg, Model):
+            selector = {"type": arg}
+        else:
+            raise TypeError("selector must be a dictionary, string or plot object.")
+
+    elif 'selector' in kwargs:
+        if len(kwargs) == 1:
+            selector = kwargs['selector']
+        else:
+            raise TypeError("when passing 'selector' keyword arg, not other keyword args may be present")
+
+    else:
+        selector = kwargs
+
+    return selector
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
