@@ -13,9 +13,9 @@ from bokeh.models import CheckboxGroup
 p = figure()
 props = dict(line_width=4, line_alpha=0.7)
 x = np.linspace(0, 4 * np.pi, 100)
-l0 = p.line(x, np.sin(x), color=Viridis3[0], legend="Line 0", **props)
-l1 = p.line(x, 4 * np.cos(x), color=Viridis3[1], legend="Line 1", **props)
-l2 = p.line(x, np.tan(x), color=Viridis3[2], legend="Line 2", **props)
+l0 = p.line(x, np.sin(x), color=Viridis3[0], legend_label="Line 0", **props)
+l1 = p.line(x, 4 * np.cos(x), color=Viridis3[1], legend_label="Line 1", **props)
+l2 = p.line(x, np.tan(x), color=Viridis3[2], legend_label="Line 2", **props)
 
 checkbox = CheckboxGroup(labels=["Line 0", "Line 1", "Line 2"], active=[0, 1, 2], width=100)
 
