@@ -21,12 +21,7 @@ export class MyFormatter extends TickFormatter {
 
     return formatted
   }
-
-  static initClass(): void {
-    this.prototype.type = "MyFormatter"
-  }
 }
-MyFormatter.initClass()
 """
 
 class MyFormatter(TickFormatter):
