@@ -21,7 +21,7 @@ template = Template("""
   <div>
     The plot embedded below is a standalone plot that was embedded using
     <fixed>autoload_static</fixed>. For more information see the
-    <a target="_blank" href="https://bokeh.pydata.org/en/latest/docs/user_guide/embed.html#static-data">
+    <a target="_blank" href="https://docs.bokeh.org/en/latest/docs/user_guide/embed.html#autoload-scripts">
     documentation</a>.
   </div>
   {{ script|safe }}
