@@ -19,7 +19,7 @@ class IndexHandler(RequestHandler):
         script = server_document('http://localhost:5006/bkapp')
         self.write(template.render(script=script, template="Tornado"))
 
-def modify_doc(doc):
+def bkapp(doc):
     df = sea_surface_temperature.copy()
     source = ColumnDataSource(data=df)
 
@@ -48,7 +48,7 @@ def modify_doc(doc):
 # bokeh.server.urls. In order to make your own end point for static resources,
 # add the following to the `extra_patterns` argument, replacing `DIR` with the desired directory.
 # (r'/DIR/(.*)', StaticFileHandler, {'path': os.path.normpath(os.path.dirname(__file__) + '/DIR')})
-server = Server({'/bkapp': modify_doc}, num_procs=4, extra_patterns=[('/', IndexHandler)])
+server = Server({'/bkapp': bkapp}, num_procs=4, extra_patterns=[('/', IndexHandler)])
 server.start()
 
 if __name__ == '__main__':
