@@ -17,8 +17,8 @@ plot.add_layout(LinearAxis(x_range_name='foo2', axis_label = 'foo2'), 'above')
 plot.extra_x_ranges['foo3'] = Range1d(start=0, end=1)
 plot.add_layout(LinearAxis(x_range_name='foo3', axis_label = 'foo3'), 'above')
 
-plot.line(x=[0, 1], y=[0, 1], legend='foo1', x_range_name='foo1', y_range_name='MD')
-plot.line(x=[10, 0], y=[0, 1], legend='foo2', x_range_name='foo2', y_range_name='MD', color='red')
-plot.line(x=[0, 0.5], y=[0.5, 0], legend='foo3', x_range_name='foo3', y_range_name='MD')
+plot.line(x=[0, 1], y=[0, 1], legend_label='foo1', x_range_name='foo1', y_range_name='MD')
+plot.line(x=[10, 0], y=[0, 1], legend_label='foo2', x_range_name='foo2', y_range_name='MD', color='red')
+plot.line(x=[0, 0.5], y=[0.5, 0], legend_label='foo3', x_range_name='foo3', y_range_name='MD')
 
 save(plot)
