@@ -14,10 +14,10 @@ for ycoeff in coeffs:
     row = []
     for xcoeff in coeffs:
         fig = figure(plot_height=200, plot_width=200)
-        fig.xaxis[0].formatter.use_scientific = False
-        fig.yaxis[0].formatter.use_scientific = False
-        fig.xaxis[0].major_label_orientation = "vertical"
-        fig.yaxis[0].major_label_orientation = "horizontal"
+        fig.xaxis.formatter.use_scientific = False
+        fig.yaxis.formatter.use_scientific = False
+        fig.xaxis.major_label_orientation = "vertical"
+        fig.yaxis.major_label_orientation = "horizontal"
         fig.scatter(V*xcoeff, V*ycoeff)
         row.append(fig)
     figs.append(row)
