@@ -12,7 +12,7 @@ counts = [5, 3, 4, 2, 4, 6]
 source = ColumnDataSource(data=dict(fruits=fruits, counts=counts))
 
 p = figure(x_range=fruits, plot_height=350, toolbar_location=None, title="Fruit Counts")
-p.vbar(x='fruits', top='counts', width=0.9, source=source, legend="fruits",
+p.vbar(x='fruits', top='counts', width=0.9, source=source, legend_field="fruits",
        line_color='white', fill_color=factor_cmap('fruits', palette=Spectral6, factors=fruits))
 
 p.xgrid.grid_line_color = None
