@@ -8,9 +8,6 @@ from bokeh.sampledata.stocks import MSFT
 df = pd.DataFrame(MSFT)[:50]
 df["date"] = pd.to_datetime(df["date"])
 
-mids = (df.open + df.close)/2
-spans = abs(df.close-df.open)
-
 inc = df.close > df.open
 dec = df.open > df.close
 w = 12*60*60*1000 # half day in ms
@@ -22,8 +19,8 @@ p.xaxis.major_label_orientation = pi/4
 p.grid.grid_line_alpha=0.3
 
 p.segment(df.date, df.high, df.date, df.low, color="black")
-p.rect(df.date[inc], mids[inc], w, spans[inc], fill_color="#D5E1DD", line_color="black")
-p.rect(df.date[dec], mids[dec], w, spans[dec], fill_color="#F2583E", line_color="black")
+p.vbar(df.date[inc], w, df.open[inc], df.close[inc], fill_color="#D5E1DD", line_color="black")
+p.vbar(df.date[dec], w, df.open[dec], df.close[dec], fill_color="#F2583E", line_color="black")
 
 output_file("candlestick.html", title="candlestick.py example")
 
