@@ -43,7 +43,7 @@ p = figure(plot_width=900, plot_height=450, tooltips=TOOLTIPS, title='Densities
 p.background_fill_color = "#fafafa"
 
 p.circle('atomic_mass', 'density', size=12, source=data, color='type_color',
-         line_color="black", legend='metal', alpha=0.9)
+         line_color="black", legend_field='metal', alpha=0.9)
 
 p.legend.glyph_width = 30
 p.legend.glyph_height = 30
@@ -52,8 +52,8 @@ p.yaxis.axis_label= 'Density'
 p.xgrid.grid_line_color = None
 p.toolbar_location = None
 
-l = p.legend[0]
-p.add_layout(l, 'right')
-l.border_line_color = None
+legend = p.legend[0]
+p.add_layout(legend, 'right')
+legend.border_line_color = None
 
 show(p)
