@@ -36,8 +36,9 @@ data=dict(
 
 p = figure(title="Hoverful Scatter", tools=TOOLS, tooltips=TOOLTIPS)
 
-p.circle(x='x', y='y', radius='radius', source=data,
-         fill_color='colors', fill_alpha=0.6, line_color=None)
+r = p.circle(x='x', y='y', radius='radius', source=data,
+             fill_color='colors', fill_alpha=0.6, line_color=None)
+p.hover.renderers = [r] # hover only for circles
 
 p.text(x, y, text=inds, alpha=0.5, text_font_size="5pt",
        text_baseline="middle", text_align="center")
