@@ -9,7 +9,8 @@ p = figure(title = "Iris Morphology", background_fill_color="#fafafa")
 p.xaxis.axis_label = 'Petal Length'
 p.yaxis.axis_label = 'Sepal Width'
 
-p.scatter("petal_length", "sepal_width", source=flowers, legend="species", fill_alpha=0.4, size=12,
+p.scatter("petal_length", "sepal_width", source=flowers,
+          legend_group="species", fill_alpha=0.4, size=12,
           marker=factor_mark('species', MARKERS, SPECIES),
           color=factor_cmap('species', 'Category10_3', SPECIES))
 
