@@ -18,7 +18,7 @@ source = ColumnDataSource(dict(
 
 plot = Plot(
     title=None, plot_width=300, plot_height=300,
-    h_symmetry=False, v_symmetry=False, min_border=0, toolbar_location=None)
+    min_border=0, toolbar_location=None)
 
 glyph = Quad(left="left", right="right", top="top", bottom="bottom", fill_color="#b3de69")
 plot.add_glyph(source, glyph)
