@@ -14,7 +14,7 @@ source = ColumnDataSource(dict(x=x, y=y, text=text))
 
 plot = Plot(
     title=None, plot_width=300, plot_height=300,
-    h_symmetry=False, v_symmetry=False, min_border=0, toolbar_location=None)
+    min_border=0, toolbar_location=None)
 
 glyph = Text(x="x", y="y", text="text", angle=0.3, text_color="#96deb3")
 plot.add_glyph(source, glyph)
