@@ -1,4 +1,3 @@
-from bokeh.core.properties import value
 from bokeh.io import show, output_file
 from bokeh.models import ColumnDataSource
 from bokeh.plotting import figure
@@ -20,13 +19,13 @@ p = figure(x_range=fruits, y_range=(0, 10), plot_height=250, title="Fruit Counts
            toolbar_location=None, tools="")
 
 p.vbar(x=dodge('fruits', -0.25, range=p.x_range), top='2015', width=0.2, source=source,
-       color="#c9d9d3", legend=value("2015"))
+       color="#c9d9d3", legend_label="2015")
 
 p.vbar(x=dodge('fruits',  0.0,  range=p.x_range), top='2016', width=0.2, source=source,
-       color="#718dbf", legend=value("2016"))
+       color="#718dbf", legend_label="2016")
 
 p.vbar(x=dodge('fruits',  0.25, range=p.x_range), top='2017', width=0.2, source=source,
-       color="#e84d60", legend=value("2017"))
+       color="#e84d60", legend_label="2017")
 
 p.x_range.range_padding = 0.1
 p.xgrid.grid_line_color = None
