@@ -33,7 +33,7 @@ source = ColumnDataSource(df)
 p = figure(plot_width=900, plot_height=500, title="Periodic Table (omitting LA and AC Series)",
            x_range=groups, y_range=list(reversed(periods)), toolbar_location=None, tools="hover")
 
-p.rect("group", "period", 0.95, 0.95, source=source, fill_alpha=0.6, legend="metal",
+p.rect("group", "period", 0.95, 0.95, source=source, fill_alpha=0.6, legend_field="metal",
        color=factor_cmap('metal', palette=list(cmap.values()), factors=list(cmap.keys())))
 
 text_props = {"source": source, "text_align": "left", "text_baseline": "middle"}
