@@ -10,7 +10,7 @@ p.title.text = 'Click on legend entries to hide the corresponding lines'
 for data, name, color in zip([AAPL, IBM, MSFT, GOOG], ["AAPL", "IBM", "MSFT", "GOOG"], Spectral4):
     df = pd.DataFrame(data)
     df['date'] = pd.to_datetime(df['date'])
-    p.line(df['date'], df['close'], line_width=2, color=color, alpha=0.8, legend=name)
+    p.line(df['date'], df['close'], line_width=2, color=color, alpha=0.8, legend_label=name)
 
 p.legend.location = "top_left"
 p.legend.click_policy="hide"
