@@ -1,9 +1,8 @@
 from bokeh.io import output_file, show
-from bokeh.layouts import widgetbox
 from bokeh.models.widgets import Slider
 
 output_file("slider.html")
 
 slider = Slider(start=0, end=10, value=1, step=.1, title="Stuff")
 
-show(widgetbox(slider))
+show(slider)
