@@ -1,6 +1,5 @@
 from bokeh.io import output_file, show
 from bokeh.layouts import gridplot
-from bokeh.palettes import Viridis3
 from bokeh.plotting import figure
 
 output_file("layout_grid_convenient.html")
@@ -11,15 +10,16 @@ y1 = [10 - i for i in x]
 y2 = [abs(i - 5) for i in x]
 
 # create three plots
-s1 = figure()
-s1.circle(x, y0, size=10, color=Viridis3[0])
-s2 = figure()
-s2.triangle(x, y1, size=10, color=Viridis3[1])
-s3 = figure()
-s3.square(x, y2, size=10, color=Viridis3[2])
+s1 = figure(background_fill_color="#fafafa")
+s1.circle(x, y0, size=12, alpha=0.8, color="#53777a")
+
+s2 = figure(background_fill_color="#fafafa")
+s2.triangle(x, y1, size=12, alpha=0.8, color="#c02942")
+
+s3 = figure(background_fill_color="#fafafa")
+s3.square(x, y2, size=12, alpha=0.8, color="#d95b43")
 
 # make a grid
 grid = gridplot([s1, s2, s3], ncols=2, plot_width=250, plot_height=250)
 
-# show the results
 show(grid)
