@@ -8,14 +8,14 @@ output_file("legend_background.html")
 
 p = figure()
 
-p.circle(x, y, legend="sin(x)")
-p.line(x, y, legend="sin(x)")
+p.circle(x, y, legend_label="sin(x)")
+p.line(x, y, legend_label="sin(x)")
 
-p.line(x, 2*y, legend="2*sin(x)",
+p.line(x, 2*y, legend_label="2*sin(x)",
        line_dash=[4, 4], line_color="orange", line_width=2)
 
-p.square(x, 3*y, legend="3*sin(x)", fill_color=None, line_color="green")
-p.line(x, 3*y, legend="3*sin(x)", line_color="green")
+p.square(x, 3*y, legend_label="3*sin(x)", fill_color=None, line_color="green")
+p.line(x, 3*y, legend_label="3*sin(x)", line_color="green")
 
 #  3*sin(x) curve should be under this legend at initial viewing, so
 # we can see that the legend is transparent
