@@ -20,6 +20,7 @@ import pytest ; pytest
 # Standard library imports
 
 # External imports
+from flaky import flaky
 from selenium.webdriver.common.keys import Keys
 
 # Bokeh imports
@@ -232,8 +233,7 @@ class Test_AutocompleteInput(object):
         assert "bk-active" not in items[0].get_attribute('class')
         assert "bk-active" in items[1].get_attribute('class')
 
-    # XXX (bev) always works locally but fails intermittently (often) on TravisCI
-    @pytest.mark.skip
+    @flaky(max_runs=5)
     def test_server_on_change_no_round_trip_without_enter_or_click(self, bokeh_server_page):
         page = bokeh_server_page(modify_doc)
 
@@ -248,6 +248,7 @@ class Test_AutocompleteInput(object):
         # XXX (bev) disabled until https://github.com/bokeh/bokeh/issues/7970 is resolved
         #assert page.has_no_console_errors()
 
+    @flaky(max_runs=5)
     def test_server_on_change_round_trip_full_entry(self, bokeh_server_page):
         page = bokeh_server_page(modify_doc)
 
@@ -276,6 +277,7 @@ class Test_AutocompleteInput(object):
         results = page.results
         assert results['data']['val'] == ["12344556", "3194567289"]
 
+    @flaky(max_runs=5)
     def test_server_on_change_round_trip_partial_entry(self, bokeh_server_page):
         page = bokeh_server_page(modify_doc)
 
