@@ -20,6 +20,7 @@ import pytest ; pytest
 # Standard library imports
 
 # External imports
+from flaky import flaky
 
 # Bokeh imports
 from bokeh.layouts import column
@@ -85,8 +86,7 @@ class Test_TextInput(object):
 
         assert page.has_no_console_errors()
 
-    # XXX (bev) always works locally but fails intermittently (often) on TravisCI
-    @pytest.mark.skip
+    @flaky(max_runs=5)
     def test_server_on_change_no_round_trip_without_enter_or_click(self, bokeh_server_page):
         page = bokeh_server_page(modify_doc)
 
@@ -101,6 +101,7 @@ class Test_TextInput(object):
         # XXX (bev) disabled until https://github.com/bokeh/bokeh/issues/7970 is resolved
         #assert page.has_no_console_errors()
 
+    @flaky(max_runs=5)
     def test_server_on_change_round_trip(self, bokeh_server_page):
         page = bokeh_server_page(modify_doc)
 
