@@ -9,7 +9,7 @@ class TestBokehJS(object):
 
     def test_bokehjs(self):
         os.chdir('bokehjs')
-        proc = subprocess.Popen(["node", "make", "test"], stdout=subprocess.PIPE)
+        proc = subprocess.Popen(["node", "make", "test", "--coverage"], stdout=subprocess.PIPE)
         out, errs = proc.communicate()
         msg = out.decode('utf-8', errors='ignore')
         os.chdir('..')
